/**
 * @brief 错误码
 */
declare enum NNIMErrCode {
    ERR_SUCC = 20001,
    ERR_FAIL = 20002
}
/**
 * @brief 调用接口的返回值
 */
declare enum NNIMResult {
    NNIM_SUCC = 0,
    NNIM_ERR_PARAM_COUNT_MATCH = 1,
    NNIM_ERR_PARAM_TYPE_MATCH = 2,
    NNIM_ERR_CHATTYPE_INVALID = 3
}

/**
 * @brief 消息回调参数数据
 * @param {number}              [packet_type]       请求类型 参考NNIMPacketType
 * @param {number}              [cmd_type]          命令类型 参考NNIMCmdType
 * @param {string}              [belong_id]         当前语音房归属id，例如当前语音房归属哪个群id
 * @param {string}              [channel_id]        群id,如频道ID，群聊ID、直播间ID
 * @param {number}              [remote_user_id]    消息发送方uid
 * @param {string}              [msg]               消息内容
 * @param {number}              [msg_type]          消息类型 参考 NNIMMsgType
 * @param {string}              [session_id]        会话id
 * @param {string}              [msg_id]            消息id
 * @param {string}              [cmsg_id]           客户端消息id
 * @note
 */
interface NNIMMsgCallbackData {
    packet_type: number;
    cmd_type: number;
    belong_id: string;
    channel_id: string;
    remote_user_id: number;
    msg: string;
    msg_type: number;
    session_id: string;
    msg_id: string;
    cmsg_id: string;
}
/**
 * @brief 消息回调函数接口
 * @note
 */
interface NNIMMsgCallback {
    (data: NNIMMsgCallbackData): void;
}
/**
 * @brief 设置消息回调参数
 * @note
 */
interface NNImMsgCallbackParam {
    callback: NNIMMsgCallback;
}
/**
 * @brief 通知回调参数数据
 * @param {number}              [packet_type]       请求类型 参考NNIMPacketType
 * @param {number}              [cmd_type]          命令类型 参考NNIMCmdType
 * @param {string}              [belong_id]         当前语音房归属id，例如当前语音房归属哪个群id
 * @param {number}              [remote_user_id]    消息发送方uid
 * @param {string}              [msg]               通知内容
 * @param {string}              [title]             内容标题，推送离线时设备的一级标题
 * @param {number}              [msg_type]          消息类型 参考 NNIMMsgType
 * @param {number}              [notify_type]       通知类型 参考 NNIMNotifyType
 * @param {string}              [session_id]        会话id
 * @param {string}              [msg_id]            消息id
 * @param {string}              [cmsg_id]           客户端消息id
 * @note
 */
interface NNIMNotifyCallbackData {
    packet_type: number;
    cmd_type: number;
    belong_id: string;
    remote_user_id: number;
    msg: string;
    title: string;
    msg_type: number;
    notify_type: number;
    session_id: string;
    msg_id: string;
    cmsg_id: string;
}
/**
 * @brief 通知回调函数接口
 * @note
 */
interface NNIMNotifyCallback {
    (data: NNIMNotifyCallbackData): void;
}
/**
 * @brief 设置通知回调参数
 * @note
 */
interface NNImNotifyCallbackParam {
    callback: NNIMNotifyCallback;
}
/**
 * @brief 事件回调参数数据
 * @param {number}              [packet_type]       请求类型 参考NNIMPacketType
 * @param {number}              [cmd_type]          命令类型 参考NNIMCmdType
 * @param {string}              [device_id]         设备id
 * @param {number}              [status_code]       状态，参考NNIMErrCode
 * @param {number}              [event_type]        回执类型，参考NNIMNAckType
 * @param {string}              [session_id]        会话id
 * @param {string}              [msg_id]            消息id
 * @param {string}              [cmsg_id]           客户端消息id
 * @param {string}              [msg]               内容
 * @note
 */
interface NNIMEventCallbackData {
    packet_type: number;
    cmd_type: number;
    device_id: string;
    status_code: number;
    event_type: number;
    session_id: string;
    msg_id: string;
    cmsg_id: string;
    msg: string;
    business_type: number;
}
/**
 * @brief 事件回调函数接口
 * @note
 */
interface NNIMEventCallback {
    (data: NNIMEventCallbackData): void;
}
/**
 * @brief 设置事件回调参数
 * @note
 */
interface NNImEventCallbackParam {
    callback: NNIMEventCallback;
}
/**
 * @brief http回调参数数据
 * @param {number}              [req_type]       请求类型 参考NNIMHttpReqType
 * @param {number}              [json_body]      http请求返回数据
 * @note
 */
interface NNIMHttpCallbackData {
    req_type: number;
    json_body: string;
}
/**
 * @brief HTTP回调函数接口
 * @note
 */
interface NNIMHttpCallback {
    (data: NNIMHttpCallbackData): void;
}
/**
 * @brief 设置HTTP回调参数
 * @note
 */
interface NNImHttpCallbackParam {
    callback: NNIMHttpCallback;
}
interface commonResult<T> {
    code: NNIMResult | NNIMErrCode;
    desc?: string | undefined;
    json_param?: T | undefined;
    user_data?: string | undefined;
}
/**
 * @brief 配置参数
 * @param {string}              [res_path]                  sdk资源文件的路径，如数据库，日志
 * @param {string}              [max_log_size]              日志单文件最大大小
 * @param {string}              [num_log_files]             日志文件数量
 */
interface NNImConfigParam {
    res_path: string;
    max_log_size: number;
    num_log_files: number;
}
/**
 * @brief 初始化参数
 * @param {string}              [server_lsb_url]          im 服务器rul
 * @param {string}              [server_lsb_port]         im 服务器端口
 * @param {string}              [im_token]                im 登录token
 * @param {string}              [app_id]                  应用id
 */
interface NNImInitParam {
    server_lsb_url: string;
    server_lsb_port: string;
    im_token: string;
    app_id: string;
    userData?: string;
}
/**
 * @brief 登录参数
 * @param {string}              [user_id]                   用户id
 * @param {string}              [userData]                  userData用户自定义数据，sdk只负责传回给回调函数cb，不做任何处理(可选参数)
 */
interface NNImLoginParam {
    user_id: number;
    userData?: string;
}
/**
 * @brief 登出参数
 * @param {string}              [userData]                  userData用户自定义数据，sdk只负责传回给回调函数cb，不做任何处理(可选参数)
 */
interface NNImLogoutParam {
    userData?: string;
}

/**
 * @brief 群操作参数
 * @param {number}              [chat_type]                 聊天类型 参考 NNIMChatType
 * @param {string}              [session_id]                当前群聊会话id
 * @param {string}              [name]                      用户名
 * @param {string}              [avatarUrl]                 用户头像
 * @param {string}              [userData]                  userData 用户自定义数据，sdk只负责传回给回调函数，不做任何处理
 */
interface NNImGroupOptParam {
    chat_type: number;
    session_id: string;
    name: string;
    avatarUrl?: string;
    userData?: string;
}
/**
 * @brief 删除群成员操作参数
 * @param {number}              [chat_type]                 聊天类型 参考 NNIMChatType
 * @param {string}              [session_id]                当前群聊会话id
 * @param {string}              [user_id]                   删除群成员id
 * @param {string}              [name]                      用户名
 * @param {string}              [avatarUrl]                 用户头像
 * @param {string}              [userData]                  userData 用户自定义数据，sdk只负责传回给回调函数，不做任何处理
 */
interface NNImGroupOptMemberParam {
    chat_type: number;
    session_id: string;
    user_id: string;
    name: string;
    avatarUrl: string;
    userData?: string;
}
/**
 * @brief 订阅参数
 * @param {string}              [subscribe_type]               订阅类型 参考NNIMCmdType中的ADD_SUBSCRIBER，REMOVE_SUBSCRIBER
 * @param {string}              [subscribe_uids]               订阅的用户id列表
 * @param {string}              [userData]                  userData 用户自定义数据，sdk只负责传回给回调函数，不做任何处理
 */
interface NNImSubscribeParam {
    subscribe_type: string;
    subscribe_uids: Array<string>;
    userData?: string;
}

/**
 * @brief 发送消息参数
 * @param {number}                  [to]                     接收者
 * @param {string}                  [replyMsgId]             回复消息ID
 * @param {string}                  [sessionId]              会话ID：单聊：小的用户ID+"-"+大的用户ID组成
 * @param {string}                  [msgType]                消息类型 参考 NNIMMsgType
 * @param {string}                  [msg]                    操作内容
 * @param {string}                  [msg]                    操作内容
 * @param {string}                  [msg]                    操作内容
 * @param {string}                  [msg]                    操作内容
 * @param {string}                  [msg]                    操作内容
 * @param {string}                  [msg]                    操作内容
 * @param {string}                  [userData]               userData 用户自定义数据，sdk只负责传回给回调函数，不做任何处理
 */
interface NNImSendMessageParam {
    replyMsgId?: string;
    sessionId?: string;
    msgType: number;
    diyType: number;
    bizType: number;
    atFlag: string;
    content: string;
    cMsgId: string;
    extend1?: string;
    extend2?: string;
    extend3?: string;
    extend4?: string;
    extend5?: string;
    name: string;
    avatarUrl: string;
    channelId: string;
    toName: string;
    toAvatarUrl: string;
    replyContent: string;
}
/**
 * @brief 发送消息参数
 * @param {NNImSendMessageParam}    [param]                     消息参数 参考 NNImSendMessageParam
 * @param {string}                  [userData]                  userData 用户自定义数据，sdk只负责传回给回调函数，不做任何处理
 */
interface NNImSendMessageParamV1 {
    param: NNImSendMessageParam;
    userData?: string;
}
/**
 * @brief 发送消息参数
 * @param {number}              [chat_type]                 聊天类型 参考 NNIMChatType
 * @param {number}              [message_type]              消息类型 参考 NNIMMsgType
 * @param {string}              [belong_id]                 当前语音房归属id，例如当前语音房归属哪个群id
 * @param {string}              [channel_id]                群id,如频道ID，群聊ID、直播间ID
 * @param {string}              [msg]                       操作内容
 * @param {string}              [remote_chat_id]            用户id/群聊id/直播间id/派对房id，消息接收方
 */
interface NNImSendMessageParamV2 {
    param: NNImSendMessageParam;
    userData?: string;
    callback: Function;
}
/**
 * @brief 消息已读参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImMsgReadedParams {
    session_id: string;
    biz_type: number;
    userData?: string;
}
/**
 * @brief 消息删除参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImMsgDeleteParams {
    msg_id: Array<string>;
    session_id: string;
    name: string;
    business_type: number;
    userData?: string;
}
/**
 * @brief 消息撤回参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImMsgRevokeParams {
    msg_id: Array<string>;
    session_id: string;
    name: string;
    business_type: number;
    userData?: string;
}
/**
 * @brief 清屏参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImCleanScreenParams {
    session_id: string;
    userData?: string;
}
/**
 * @brief 清屏参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImNotifyMsgParams {
    content: string;
    title: string;
    msgType: string;
    pushContent: string;
    extend1?: string;
    extend2?: string;
    extend3?: string;
    extend4?: string;
    extend5?: string;
    name: string;
    avatarUrl: string;
}
/**
 * @brief 清屏参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImSendSingleParams {
    tos: Array<string>;
    notifyMsg: NNImNotifyMsgParams;
    userData?: string;
}
/**
 * @brief 清屏参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImSendGroupParams {
    to: string;
    notifyMsg: NNImNotifyMsgParams;
    userData?: string;
}
/**
 * @brief 消息操作参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImMessageOptParam {
    msg_id: string;
    cmsg_id: string;
    session_id: string;
    msg: string;
    business_type: number;
}
/**
 * @brief 获取历史消息参数
 * @param {number}              [count]                    消息数量
 * @param {number}              [sequence]                 消息的列表的序列
 * @param {string}              [session_id]               会话id
 */
interface NNImHistoryMsgListParam {
    count: number;
    sequence: number;
    session_id: string;
    userData?: string;
}

/**
 * @brief 获取历史消息参数
 * @param {number}              [count]                    消息数量
 * @param {number}              [sequence]                 消息的列表的序列
 * @param {string}              [session_id]               会话id
 */
interface NNImConversationListParam {
    userData?: string;
}
/**
 * @brief 获取历史消息参数
 * @param {number}              [count]                    消息数量
 * @param {number}              [sequence]                 消息的列表的序列
 * @param {string}              [session_id]               会话id
 */
interface NNImConversationMsgRemindParam {
    session_id: string;
    isRemind: boolean;
    userData?: string;
}
/**
 * @brief 获取历史消息参数
 * @param {number}              [count]                    消息数量
 * @param {number}              [sequence]                 消息的列表的序列
 * @param {string}              [session_id]               会话id
 */
interface NNImPinConversationParam {
    session_id: string;
    isPinned: boolean;
    userData?: string;
}
/**
 * @brief 获取历史消息参数
 * @param {number}              [count]                    消息数量
 * @param {number}              [sequence]                 消息的列表的序列
 * @param {string}              [session_id]               会话id
 */
interface NNImDeleteConversationParam {
    session_id: string;
    userData?: string;
}

export { NNIMEventCallback, NNIMEventCallbackData, NNIMHttpCallback, NNIMHttpCallbackData, NNIMMsgCallback, NNIMMsgCallbackData, NNIMNotifyCallback, NNIMNotifyCallbackData, NNImCleanScreenParams, NNImConfigParam, NNImConversationListParam, NNImConversationMsgRemindParam, NNImDeleteConversationParam, NNImEventCallbackParam, NNImGroupOptMemberParam, NNImGroupOptParam, NNImHistoryMsgListParam, NNImHttpCallbackParam, NNImInitParam, NNImLoginParam, NNImLogoutParam, NNImMessageOptParam, NNImMsgCallbackParam, NNImMsgDeleteParams, NNImMsgReadedParams, NNImMsgRevokeParams, NNImNotifyCallbackParam, NNImNotifyMsgParams, NNImPinConversationParam, NNImSendGroupParams, NNImSendMessageParam, NNImSendMessageParamV1, NNImSendMessageParamV2, NNImSendSingleParams, NNImSubscribeParam, commonResult };
